==> computer_use_ootb_internal-0.0.187.tar.gz: computer_use_ootb_internal-0.0.187/src/computer_use_ootb_internal/preparation/pr_prepare.py <==
import os
import platform
import subprocess
import logging
from pathlib import Path
import time

log = logging.getLogger(__name__)

def run_preparation(state):
    """
    Performs environment preparation specific to Adobe Premiere Pro on Windows.
    Opens a specific template project file located on the user's desktop and maximizes the window.
    Kills existing Premiere Pro processes first.
    """
    if platform.system() != "Windows":
        log.warning("Premiere Pro preparation skipped: Not running on Windows.")
        return

    log.info(f"Premiere Pro preparation: Starting on Windows platform...")

    try:
        # Determine the desktop path for Windows
        try:
            username = os.environ.get("USERNAME", "")
            if not username:
                log.error("Could not determine Windows username from environment")
                return
            
            log.info(f"Using Windows username: {username}")
            desktop_path = Path(f"C:/Users/{username}/Desktop")
            
            if not desktop_path.exists():
                log.error(f"Desktop path not found at: {desktop_path}")
                alt_path = Path(f"C:/Documents and Settings/{username}/Desktop")
                if alt_path.exists():
                    desktop_path = alt_path
                    log.info(f"Using alternative desktop path: {desktop_path}")
                else:
                    log.error("Failed to find user's desktop directory")
                    return
            
        except Exception as e:
            log.error(f"Error determining Windows user desktop: {e}", exc_info=True)
            return
            
        # Construct path to template file
        template_file = desktop_path / "template.prproj" # Changed extension
        log.info(f"Looking for template file at: {template_file}")

        if not template_file.exists():
            log.error(f"Template file not found at: {template_file}")
            return

        # --- Kill existing Premiere Pro processes --- 
        log.info("Attempting to close existing Adobe Premiere Pro processes...")
        try:
            # Command to forcefully terminate Premiere Pro processes by image name
            # Assuming the process name includes the year for 2024 version.
            kill_cmd = ['taskkill', '/F', '/IM', 'Adobe Premiere Pro 2024.exe'] # Updated process name
            kill_result = subprocess.run(kill_cmd,
                                       capture_output=True, text=True, check=False)
            
            # Check taskkill result
            if kill_result.returncode == 0:
                log.info("Successfully sent termination signal to Adobe Premiere Pro 2024.exe processes.")
            elif "not found" in kill_result.stderr.lower() or "not found" in kill_result.stdout.lower():
                 log.info("No running Adobe Premiere Pro 2024.exe processes found to close.")
            else:
                 log.warning(f"taskkill command finished with return code {kill_result.returncode}. Output: {kill_result.stdout} Stderr: {kill_result.stderr}")
            time.sleep(2) # Increased sleep time slightly for potentially heavier app
        except FileNotFoundError:
            log.error("Error: 'taskkill' command not found. Make sure it's in the system PATH.")
        except Exception as e:
            log.error(f"Error occurred while trying to close Premiere Pro: {e}", exc_info=True)
        # --- End of kill process --- 

        # Open the file with Premiere Pro maximized on Windows
        try:
            pr_executable = r"C:\Program Files\Adobe\Adobe Premiere Pro 2024\Adobe Premiere Pro.exe"
            # Check if template exists and construct command accordingly
            if template_file.exists():
                log.info(f"Template file found. Attempting to open {template_file} with Premiere Pro maximized...")
                # Use empty title "" for start when executable path has spaces
                cmd = ['cmd', '/c', 'start', '/max', '""', pr_executable, str(template_file)]
            else:
                log.info(f"Template file not found. Attempting to launch Premiere Pro maximized...")
                cmd = ['cmd', '/c', 'start', '/max', '""', pr_executable]

            log.info(f"Executing command: {' '.join(cmd)}")
            print(f"[DEBUG] Attempting command in pr_prepare: {' '.join(cmd)}")
            result = subprocess.run(cmd, check=False, capture_output=True, text=True, creationflags=subprocess.CREATE_NO_WINDOW)

            # ADDED PRINTS for result
            print(f"[DEBUG] pr_prepare command result:")
            print(f"[DEBUG]   Return Code: {result.returncode}")
            print(f"[DEBUG]   Stdout: {result.stdout.strip() if result.stdout else ''}")
            print(f"[DEBUG]   Stderr: {result.stderr.strip() if result.stderr else ''}")

            if result.returncode == 0:
                log.info(f"Successfully executed command for Premiere Pro.")
            else:
                log.error(f"Error executing command for Premiere Pro: {result.stderr.strip() if result else 'Command not run'}")
                if result and result.stdout:
                    log.error(f"Stdout from start command: {result.stdout.strip()}")
        except FileNotFoundError:
             log.error("Error: 'cmd' or 'start' command not found. Ensure system PATH is configured correctly.")
        except Exception as e:
            log.error(f"Exception opening Premiere Pro on Windows: {e}", exc_info=True)
                
    except Exception as e:
        log.error(f"An unexpected error occurred during Premiere Pro preparation: {e}", exc_info=True)

==> computer_use_ootb_internal-0.0.191.tar.gz: computer_use_ootb_internal-0.0.191/src/computer_use_ootb_internal/preparation/pr_prepare.py <==
import os
import platform
import subprocess
import logging
from pathlib import Path
import time

log = logging.getLogger(__name__)

def run_preparation(state):
    """
    Performs environment preparation specific to Adobe Premiere Pro on Windows.
    Opens a specific template project file located on the user's desktop and maximizes the window.
    Kills existing Premiere Pro processes first.
    """
    if platform.system() != "Windows":
        log.warning("Premiere Pro preparation skipped: Not running on Windows.")
        return

    log.info(f"Premiere Pro preparation: Starting on Windows platform...")

    try:
        # Determine the desktop path for Windows
        try:
            username = os.environ.get("USERNAME", "")
            if not username:
                log.error("Could not determine Windows username from environment")
                return
            
            log.info(f"Using Windows username: {username}")
            desktop_path = Path(f"C:/Users/{username}/Desktop")
            
            if not desktop_path.exists():
                log.error(f"Desktop path not found at: {desktop_path}")
                alt_path = Path(f"C:/Documents and Settings/{username}/Desktop")
                if alt_path.exists():
                    desktop_path = alt_path
                    log.info(f"Using alternative desktop path: {desktop_path}")
                else:
                    log.error("Failed to find user's desktop directory")
                    return
            
        except Exception as e:
            log.error(f"Error determining Windows user desktop: {e}", exc_info=True)
            return
            
        # Construct path to template file
        template_file = desktop_path / "template.prproj" # Changed extension
        log.info(f"Looking for template file at: {template_file}")

        template_exists = template_file.exists()
        if not template_exists:
            log.warning(f"Template file not found at: {template_file}. Will attempt to launch Premiere Pro directly.")

        # --- Kill existing Premiere Pro processes --- 
        log.info("Attempting to close existing Adobe Premiere Pro processes...")
        try:
            # Command to forcefully terminate Premiere Pro processes by image name
            # Assuming the process name includes the year for 2024 version.
            kill_cmd = ['taskkill', '/F', '/IM', 'Adobe Premiere Pro 2024.exe'] # Updated process name
            kill_result = subprocess.run(kill_cmd,
                                       capture_output=True, text=True, check=False)
            
            # Check taskkill result
            if kill_result.returncode == 0:
                log.info("Successfully sent termination signal to Adobe Premiere Pro 2024.exe processes.")
            elif "not found" in kill_result.stderr.lower() or "not found" in kill_result.stdout.lower():
                 log.info("No running Adobe Premiere Pro 2024.exe processes found to close.")
            else:
                 log.warning(f"taskkill command finished with return code {kill_result.returncode}. Output: {kill_result.stdout} Stderr: {kill_result.stderr}")
            time.sleep(2) # Increased sleep time slightly for potentially heavier app
        except FileNotFoundError:
            log.error("Error: 'taskkill' command not found. Make sure it's in the system PATH.")
        except Exception as e:
            log.error(f"Error occurred while trying to close Premiere Pro: {e}", exc_info=True)
        # --- End of kill process --- 

        # Open the file with Premiere Pro maximized on Windows
        try:
            pr_executable = r"C:\Program Files\Adobe\Adobe Premiere Pro 2024\Adobe Premiere Pro.exe"
            # Check if template exists and construct command accordingly
            if template_exists:
                log.info(f"Template file found. Attempting to open {template_file} with Premiere Pro maximized...")
                # Use a dummy title "PR" for start instead of empty string
                cmd = ['cmd', '/c', 'start', '/max', '"PR"', pr_executable, str(template_file)]
            else:
                log.info(f"Template file not found. Attempting to launch Premiere Pro maximized...")
                cmd = ['cmd', '/c', 'start', '/max', '"PR"', pr_executable]

            log.info(f"Executing command: {' '.join(cmd)}")
            print(f"[DEBUG] Attempting command in pr_prepare: {' '.join(cmd)}")
            result = subprocess.run(cmd, check=False, capture_output=True, text=True, creationflags=subprocess.CREATE_NO_WINDOW)

            # ADDED PRINTS for result
            print(f"[DEBUG] pr_prepare command result:")
            print(f"[DEBUG]   Return Code: {result.returncode}")
            print(f"[DEBUG]   Stdout: {result.stdout.strip() if result.stdout else ''}")
            print(f"[DEBUG]   Stderr: {result.stderr.strip() if result.stderr else ''}")

            if result.returncode == 0:
                log.info(f"Successfully executed command for Premiere Pro.")
            else:
                log.error(f"Error executing command for Premiere Pro: {result.stderr.strip() if result else 'Command not run'}")
                if result and result.stdout:
                    log.error(f"Stdout from start command: {result.stdout.strip()}")
        except FileNotFoundError:
             log.error("Error: 'cmd' or 'start' command not found. Ensure system PATH is configured correctly.")
        except Exception as e:
            log.error(f"Exception opening Premiere Pro on Windows: {e}", exc_info=True)
                
    except Exception as e:
        log.error(f"An unexpected error occurred during Premiere Pro preparation: {e}", exc_info=True)
